# Toxopy

[![DeepSource](https://static.deepsource.io/deepsource-badge-light-mini.svg)](https://deepsource.io/gh/bchaselab/Toxopy/?ref=repository-badge) [![PEP8](https://img.shields.io/badge/code%20style-pep8-orange.svg)](https://www.python.org/dev/peps/pep-0008/)

Object-specific python package to run automated tasks in the Chase Lab

## Installation
```bash
$ pip install toxopy
```
